## ---------------------------------------------------------------------
##
## Copyright (C) 2012 - 2020 by the deal.II authors
##
## This file is part of the deal.II library.
##
## The deal.II library is free software; you can use it, redistribute
## it, and/or modify it under the terms of the GNU Lesser General
## Public License as published by the Free Software Foundation; either
## version 2.1 of the License, or (at your option) any later version.
## The full text of the license can be found in the file LICENSE.md at
## the top level directory of deal.II.
##
## ---------------------------------------------------------------------


########################################################################
##                                                                    ##
##               The deal.II project configuration file               ##
##                                                                    ##
########################################################################


#
# General information
#

SET(DEAL_II_PACKAGE_NAME "deal.II")
SET(DEAL_II_PACKAGE_VERSION "9.3.2")
SET(DEAL_II_PACKAGE_VENDOR "The deal.II Authors <http://www.dealii.org/>")
SET(DEAL_II_PACKAGE_DESCRIPTION "Library for solving partial differential equations with the finite element method")

SET(DEAL_II_VERSION_MAJOR "9")
SET(DEAL_II_VERSION_MINOR "3")
SET(DEAL_II_VERSION_SUBMINOR "2")
SET(DEAL_II_VERSION "9.3.2")

SET(DEAL_II_GIT_BRANCH "")
SET(DEAL_II_GIT_REVISION "")
SET(DEAL_II_GIT_SHORTREV "")
SET(DEAL_II_GIT_TAG "")

SET(DEAL_II_PROJECT_CONFIG_NAME "deal.II")

SET(DEAL_II_BUILD_TYPE "DebugRelease")
SET(DEAL_II_BUILD_TYPES "DEBUG;RELEASE")


#
# Information about the project location
#

SET(DEAL_II_DOCHTML_RELDIR "share/doc/libdeal.ii-doc/html")
SET(DEAL_II_DOCREADME_RELDIR "share/doc/libdeal.ii-doc")
SET(DEAL_II_EXAMPLES_RELDIR "share/doc/libdeal.ii-doc/examples")
SET(DEAL_II_EXECUTABLE_RELDIR "bin")
SET(DEAL_II_INCLUDE_RELDIR "include")
SET(DEAL_II_LIBRARY_RELDIR "lib/x86_64-linux-gnu")
SET(DEAL_II_PROJECT_CONFIG_RELDIR "share/cmake/deal.II")
SET(DEAL_II_SHARE_RELDIR "share/deal.ii/")

#
# Determine DEAL_II_PATH from CMAKE_CURRENT_LIST_DIR:
#

SET(DEAL_II_PATH "${CMAKE_CURRENT_LIST_DIR}")
SET(_path "${DEAL_II_PROJECT_CONFIG_RELDIR}")
WHILE(NOT "${_path}" STREQUAL "")
  GET_FILENAME_COMPONENT(DEAL_II_PATH "${DEAL_II_PATH}" PATH)
  GET_FILENAME_COMPONENT(_path "${_path}" PATH)
ENDWHILE()

#
# Print a message after inclusion of this file:
#

SET(DEAL_II_PROJECT_CONFIG_INCLUDED TRUE)

SET(DEAL_II_BUILD_DIR FALSE)

IF(NOT ${DEAL_II_PACKAGE_NAME}_FIND_QUIETLY)
  IF(DEAL_II_BUILD_DIR)
    MESSAGE(STATUS
      "Using the ${DEAL_II_PACKAGE_NAME}-${DEAL_II_PACKAGE_VERSION} build directory found at ${DEAL_II_PATH}"
      )
  ELSE()
    MESSAGE(STATUS
      "Using the ${DEAL_II_PACKAGE_NAME}-${DEAL_II_PACKAGE_VERSION} installation found at ${DEAL_II_PATH}"
      )
  ENDIF()
ENDIF()


#
# Include all convenience macros:
#

FILE(GLOB _macro_files
  "${DEAL_II_PATH}/${DEAL_II_SHARE_RELDIR}/macros/*.cmake"
  )
FOREACH(file ${_macro_files})
  IF(NOT ${DEAL_II_PACKAGE_NAME}_FIND_QUIETLY)
    MESSAGE(STATUS "Include macro ${file}")
  ENDIF()
  INCLUDE(${file})
ENDFOREACH()


#
# Compiler and linker configuration
#

SET(DEAL_II_CXX_COMPILER "/usr/bin/c++")
SET(DEAL_II_C_COMPILER "/usr/bin/cc")

# used for all targets:
SET(DEAL_II_CXX_FLAGS "-pedantic -fPIC -Wall -Wextra -Wmissing-braces -Woverloaded-virtual -Wpointer-arith -Wsign-compare  -Wswitch -Wsynth -Wwrite-strings -Wno-placement-new  -Wno-literal-suffix -Wno-psabi -Wno-class-memaccess -g -O2 -ffile-prefix-map=/build/deal.ii-b17lty/deal.ii-9.3.2=. -fstack-protector-strong -Wformat -Werror=format-security -Wdate-time -D_FORTIFY_SOURCE=2 -Wno-nonnull-compare -Wno-address -Wno-unused-local-typedefs")

# _additionally_ used for debug targets:
SET(DEAL_II_CXX_FLAGS_DEBUG "-O0 -ggdb -Wa,--compress-debug-sections")

# _additionally_ used for release targets:
SET(DEAL_II_CXX_FLAGS_RELEASE "-O2 -funroll-loops -funroll-all-loops -fstrict-aliasing -Wno-unused-local-typedefs")

# used for all targets:
SET(DEAL_II_LINKER_FLAGS "-rdynamic -fuse-ld=gold -Wl,-Bsymbolic-functions -Wl,-z,relro")

# _additionally_ used for debug targets:
SET(DEAL_II_LINKER_FLAGS_DEBUG "-ggdb")

# _additionally_ used for release targets:
SET(DEAL_II_LINKER_FLAGS_RELEASE "")

# used for all targets:
SET(DEAL_II_USER_DEFINITIONS "BOOST_NO_AUTO_PTR")

# _additionally_ used for debug targets:
SET(DEAL_II_USER_DEFINITIONS_DEBUG "DEBUG")

# _additionally_ used for release targets:
SET(DEAL_II_USER_DEFINITIONS_RELEASE "")

#
# MPI runtime:
#

SET(DEAL_II_MPIEXEC "/usr/bin/mpiexec")
SET(DEAL_II_MPIEXEC_NUMPROC_FLAG "-n")
SET(DEAL_II_MPIEXEC_PREFLAGS "")
SET(DEAL_II_MPIEXEC_POSTFLAGS "")

#
# CUDA specific setup:
#
SET(CMAKE_CUDA_ARCHITECTURES "")

#
# Build a static executable:
#

SET(DEAL_II_STATIC_EXECUTABLE "OFF")


#
# Information about include directories and libraries
#

# Full list of include directories:
SET(DEAL_II_INCLUDE_DIRS "${DEAL_II_PATH}/${DEAL_II_INCLUDE_RELDIR};/usr/lib/x86_64-linux-gnu/openmpi/include;/usr/lib/x86_64-linux-gnu/openmpi/include/openmpi;/usr/include;/usr/include/trilinos;/usr/include/hdf5/openmpi;/usr/include/scotch;/usr/include/suitesparse;/usr/include/petsc;/usr/lib/x86_64-linux-gnu/hdf5/openmpi/include;/usr/include/opencascade;/usr/include/slepc")

# Full list of libraries for the debug target:
SET(DEAL_II_LIBRARIES_DEBUG "${DEAL_II_PATH}/lib/x86_64-linux-gnu/libdeal.ii.g.so;/usr/lib/x86_64-linux-gnu/libtrilinos_pike-blackbox.so;/usr/lib/x86_64-linux-gnu/libtrilinos_trilinoscouplings.so;/usr/lib/x86_64-linux-gnu/libtrilinos_piro.so;/usr/lib/x86_64-linux-gnu/libtrilinos_rol.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_muelu.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_muelu_pce_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_muelu_mp_16_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_ifpack2.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_ifpack2_pce_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_ifpack2_mp_16_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_amesos2.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_xpetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_xpetra_pce_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_xpetra_mp_16_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_tpetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_tpetraext_pce_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_tpetra_pce_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_tpetra_sd_pce_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_tpetraext_mp_16_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_tpetra_mp_16_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_tpetra_sd_mp_16_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_sacado.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos.so;/usr/lib/x86_64-linux-gnu/libtrilinos_rythmos.so;/usr/lib/x86_64-linux-gnu/libtrilinos_shylu_ddcommon.so;/usr/lib/x86_64-linux-gnu/libtrilinos_shylu_ddfrosch.so;/usr/lib/x86_64-linux-gnu/libtrilinos_shylu_ddbddc.so;/usr/lib/x86_64-linux-gnu/libtrilinos_zoltan2sphynx.so;/usr/lib/x86_64-linux-gnu/libtrilinos_muelu-adapters.so;/usr/lib/x86_64-linux-gnu/libtrilinos_muelu-interface.so;/usr/lib/x86_64-linux-gnu/libtrilinos_muelu.so;/usr/lib/x86_64-linux-gnu/libtrilinos_moertel.so;/usr/lib/x86_64-linux-gnu/libtrilinos_locatpetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_locathyra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_locaepetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_localapack.so;/usr/lib/x86_64-linux-gnu/libtrilinos_loca.so;/usr/lib/x86_64-linux-gnu/libtrilinos_noxepetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_noxlapack.so;/usr/lib/x86_64-linux-gnu/libtrilinos_nox.so;/usr/lib/x86_64-linux-gnu/libtrilinos_phalanx.so;/usr/lib/x86_64-linux-gnu/libtrilinos_intrepid2.so;/usr/lib/x86_64-linux-gnu/libtrilinos_intrepid.so;/usr/lib/x86_64-linux-gnu/libtrilinos_teko.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stratimikos.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stratimikosbelos.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stratimikosamesos2.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stratimikosaztecoo.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stratimikosamesos.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stratimikosml.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stratimikosifpack.so;/usr/lib/x86_64-linux-gnu/libtrilinos_ifpack2-adapters.so;/usr/lib/x86_64-linux-gnu/libtrilinos_ifpack2.so;/usr/lib/x86_64-linux-gnu/libtrilinos_anasazitpetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_ModeLaplace.so;/usr/lib/x86_64-linux-gnu/libtrilinos_anasaziepetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_anasazi.so;/usr/lib/x86_64-linux-gnu/libtrilinos_komplex.so;/usr/lib/x86_64-linux-gnu/libtrilinos_amesos2.so;/usr/lib/x86_64-linux-gnu/libtrilinos_tacho.so;/usr/lib/x86_64-linux-gnu/libtrilinos_shylu_nodehts.so;/usr/lib/x86_64-linux-gnu/libtrilinos_belosxpetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_belostpetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_belosepetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_belos.so;/usr/lib/x86_64-linux-gnu/libtrilinos_ml.so;/usr/lib/x86_64-linux-gnu/libtrilinos_ifpack.so;/usr/lib/x86_64-linux-gnu/libtrilinos_zoltan2.so;/usr/lib/x86_64-linux-gnu/libtrilinos_pamgen_extras.so;/usr/lib/x86_64-linux-gnu/libtrilinos_pamgen.so;/usr/lib/x86_64-linux-gnu/libtrilinos_amesos.so;/usr/lib/x86_64-linux-gnu/libtrilinos_galeri-xpetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_galeri-epetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_aztecoo.so;/usr/lib/x86_64-linux-gnu/libtrilinos_dpliris.so;/usr/lib/x86_64-linux-gnu/libtrilinos_isorropia.so;/usr/lib/x86_64-linux-gnu/libtrilinos_xpetra-sup.so;/usr/lib/x86_64-linux-gnu/libtrilinos_xpetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_thyratpetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_thyraepetraext.so;/usr/lib/x86_64-linux-gnu/libtrilinos_thyraepetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_thyracore.so;/usr/lib/x86_64-linux-gnu/libtrilinos_trilinosss.so;/usr/lib/x86_64-linux-gnu/libtrilinos_tpetraext.so;/usr/lib/x86_64-linux-gnu/libtrilinos_tpetrainout.so;/usr/lib/x86_64-linux-gnu/libtrilinos_tpetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_kokkostsqr.so;/usr/lib/x86_64-linux-gnu/libtrilinos_tpetraclassiclinalg.so;/usr/lib/x86_64-linux-gnu/libtrilinos_tpetraclassicnodeapi.so;/usr/lib/x86_64-linux-gnu/libtrilinos_tpetraclassic.so;/usr/lib/x86_64-linux-gnu/libtrilinos_epetraext.so;/usr/lib/x86_64-linux-gnu/libtrilinos_triutils.so;/usr/lib/x86_64-linux-gnu/libtrilinos_shards.so;/usr/lib/x86_64-linux-gnu/libtrilinos_zoltan.so;/usr/lib/x86_64-linux-gnu/libtrilinos_epetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_sacado.so;/usr/lib/x86_64-linux-gnu/libtrilinos_rtop.so;/usr/lib/x86_64-linux-gnu/libtrilinos_kokkoskernels.so;/usr/lib/x86_64-linux-gnu/libtrilinos_teuchoskokkoscomm.so;/usr/lib/x86_64-linux-gnu/libtrilinos_teuchoskokkoscompat.so;/usr/lib/x86_64-linux-gnu/libtrilinos_teuchosremainder.so;/usr/lib/x86_64-linux-gnu/libtrilinos_teuchosnumerics.so;/usr/lib/x86_64-linux-gnu/libtrilinos_teuchoscomm.so;/usr/lib/x86_64-linux-gnu/libtrilinos_teuchosparameterlist.so;/usr/lib/x86_64-linux-gnu/libtrilinos_teuchosparser.so;/usr/lib/x86_64-linux-gnu/libtrilinos_teuchoscore.so;/usr/lib/x86_64-linux-gnu/libtrilinos_kokkosalgorithms.so;/usr/lib/x86_64-linux-gnu/libtrilinos_kokkoscontainers.so;/usr/lib/x86_64-linux-gnu/libtrilinos_kokkoscore.so;/usr/lib/x86_64-linux-gnu/libtbb.so;/usr/lib/x86_64-linux-gnu/libsmumps.so;/usr/lib/x86_64-linux-gnu/libdmumps.so;/usr/lib/x86_64-linux-gnu/libcmumps.so;/usr/lib/x86_64-linux-gnu/libzmumps.so;/usr/lib/x86_64-linux-gnu/libpord.so;/usr/lib/x86_64-linux-gnu/libmumps_common.so;/usr/lib/x86_64-linux-gnu/hdf5/openmpi/libhdf5.so;/usr/lib/x86_64-linux-gnu/libptscotch.so;/usr/lib/x86_64-linux-gnu/libptscotcherr.so;/usr/lib/x86_64-linux-gnu/libscotch.so;/usr/lib/x86_64-linux-gnu/libscotcherr.so;/usr/lib/x86_64-linux-gnu/libdl.a;/usr/lib/x86_64-linux-gnu/openmpi/lib/libmpi_cxx.so;/usr/lib/x86_64-linux-gnu/libumfpack.so;/usr/lib/x86_64-linux-gnu/libcholmod.so;/usr/lib/x86_64-linux-gnu/libccolamd.so;/usr/lib/x86_64-linux-gnu/libcolamd.so;/usr/lib/x86_64-linux-gnu/libcamd.so;/usr/lib/x86_64-linux-gnu/libsuitesparseconfig.so;/usr/lib/x86_64-linux-gnu/libamd.so;/usr/lib/x86_64-linux-gnu/libmetis.so;rt;/usr/lib/x86_64-linux-gnu/libadolc.so;/usr/lib/x86_64-linux-gnu/libboost_iostreams.so;/usr/lib/x86_64-linux-gnu/libboost_serialization.so;/usr/lib/x86_64-linux-gnu/libboost_system.so;/usr/lib/x86_64-linux-gnu/libboost_thread.so;/usr/lib/x86_64-linux-gnu/libboost_regex.so;/usr/lib/x86_64-linux-gnu/libboost_chrono.so;/usr/lib/x86_64-linux-gnu/libboost_date_time.so;/usr/lib/x86_64-linux-gnu/libboost_atomic.so;/usr/lib/x86_64-linux-gnu/libparpack.so;/usr/lib/x86_64-linux-gnu/libarpack.so;/usr/lib/x86_64-linux-gnu/libassimp.so;/usr/lib/x86_64-linux-gnu/libgmsh.so;/usr/lib/x86_64-linux-gnu/libgsl.so;/usr/lib/x86_64-linux-gnu/libgslcblas.so;/usr/lib/x86_64-linux-gnu/hdf5/openmpi/lib/lib/libhdf5_hl.so;/usr/lib/x86_64-linux-gnu/hdf5/openmpi/lib/lib/libhdf5.so;/usr/lib/x86_64-linux-gnu/libmuparser.so;/usr/lib/x86_64-linux-gnu/libTKBO.so;/usr/lib/x86_64-linux-gnu/libTKBool.so;/usr/lib/x86_64-linux-gnu/libTKBRep.so;/usr/lib/x86_64-linux-gnu/libTKernel.so;/usr/lib/x86_64-linux-gnu/libTKFeat.so;/usr/lib/x86_64-linux-gnu/libTKFillet.so;/usr/lib/x86_64-linux-gnu/libTKG2d.so;/usr/lib/x86_64-linux-gnu/libTKG3d.so;/usr/lib/x86_64-linux-gnu/libTKGeomAlgo.so;/usr/lib/x86_64-linux-gnu/libTKGeomBase.so;/usr/lib/x86_64-linux-gnu/libTKHLR.so;/usr/lib/x86_64-linux-gnu/libTKIGES.so;/usr/lib/x86_64-linux-gnu/libTKMath.so;/usr/lib/x86_64-linux-gnu/libTKMesh.so;/usr/lib/x86_64-linux-gnu/libTKOffset.so;/usr/lib/x86_64-linux-gnu/libTKPrim.so;/usr/lib/x86_64-linux-gnu/libTKShHealing.so;/usr/lib/x86_64-linux-gnu/libTKSTEP.so;/usr/lib/x86_64-linux-gnu/libTKSTEPAttr.so;/usr/lib/x86_64-linux-gnu/libTKSTEPBase.so;/usr/lib/x86_64-linux-gnu/libTKSTEP209.so;/usr/lib/x86_64-linux-gnu/libTKSTL.so;/usr/lib/x86_64-linux-gnu/libTKTopAlgo.so;/usr/lib/x86_64-linux-gnu/libTKXSBase.so;/usr/lib/x86_64-linux-gnu/libp4est.so;/usr/lib/x86_64-linux-gnu/libsc.so;/usr/lib/x86_64-linux-gnu/libscalapack-openmpi.so;/usr/lib/x86_64-linux-gnu/liblapack.so;/usr/lib/x86_64-linux-gnu/libblas.so;/usr/lib/x86_64-linux-gnu/libmpi_usempif08.so;/usr/lib/x86_64-linux-gnu/libmpi_usempi_ignore_tkr.so;/usr/lib/x86_64-linux-gnu/libmpi_mpifh.so;/usr/lib/x86_64-linux-gnu/openmpi/lib/libmpi.so;/usr/lib/x86_64-linux-gnu/libopen-rte.so;/usr/lib/x86_64-linux-gnu/libopen-pal.so;/usr/lib/x86_64-linux-gnu/libhwloc.so;/usr/lib/x86_64-linux-gnu/libevent_core.so;/usr/lib/x86_64-linux-gnu/libevent_pthreads.so;m;/usr/lib/x86_64-linux-gnu/libz.so;/usr/lib/x86_64-linux-gnu/libslepc.so;/usr/lib/x86_64-linux-gnu/libpetsc.so;/usr/lib/x86_64-linux-gnu/libsundials_idas.so;/usr/lib/x86_64-linux-gnu/libsundials_arkode.so;/usr/lib/x86_64-linux-gnu/libsundials_kinsol.so;/usr/lib/x86_64-linux-gnu/libsundials_nvecserial.so;/usr/lib/x86_64-linux-gnu/libsundials_nvecparallel.so")

# Full list of libraries for the release target:
SET(DEAL_II_LIBRARIES_RELEASE "${DEAL_II_PATH}/lib/x86_64-linux-gnu/libdeal.ii.so;/usr/lib/x86_64-linux-gnu/libtrilinos_pike-blackbox.so;/usr/lib/x86_64-linux-gnu/libtrilinos_trilinoscouplings.so;/usr/lib/x86_64-linux-gnu/libtrilinos_piro.so;/usr/lib/x86_64-linux-gnu/libtrilinos_rol.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_muelu.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_muelu_pce_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_muelu_mp_16_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_ifpack2.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_ifpack2_pce_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_ifpack2_mp_16_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_amesos2.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_xpetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_xpetra_pce_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_xpetra_mp_16_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_tpetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_tpetraext_pce_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_tpetra_pce_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_tpetra_sd_pce_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_tpetraext_mp_16_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_tpetra_mp_16_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_tpetra_sd_mp_16_serial.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos_sacado.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stokhos.so;/usr/lib/x86_64-linux-gnu/libtrilinos_rythmos.so;/usr/lib/x86_64-linux-gnu/libtrilinos_shylu_ddcommon.so;/usr/lib/x86_64-linux-gnu/libtrilinos_shylu_ddfrosch.so;/usr/lib/x86_64-linux-gnu/libtrilinos_shylu_ddbddc.so;/usr/lib/x86_64-linux-gnu/libtrilinos_zoltan2sphynx.so;/usr/lib/x86_64-linux-gnu/libtrilinos_muelu-adapters.so;/usr/lib/x86_64-linux-gnu/libtrilinos_muelu-interface.so;/usr/lib/x86_64-linux-gnu/libtrilinos_muelu.so;/usr/lib/x86_64-linux-gnu/libtrilinos_moertel.so;/usr/lib/x86_64-linux-gnu/libtrilinos_locatpetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_locathyra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_locaepetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_localapack.so;/usr/lib/x86_64-linux-gnu/libtrilinos_loca.so;/usr/lib/x86_64-linux-gnu/libtrilinos_noxepetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_noxlapack.so;/usr/lib/x86_64-linux-gnu/libtrilinos_nox.so;/usr/lib/x86_64-linux-gnu/libtrilinos_phalanx.so;/usr/lib/x86_64-linux-gnu/libtrilinos_intrepid2.so;/usr/lib/x86_64-linux-gnu/libtrilinos_intrepid.so;/usr/lib/x86_64-linux-gnu/libtrilinos_teko.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stratimikos.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stratimikosbelos.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stratimikosamesos2.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stratimikosaztecoo.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stratimikosamesos.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stratimikosml.so;/usr/lib/x86_64-linux-gnu/libtrilinos_stratimikosifpack.so;/usr/lib/x86_64-linux-gnu/libtrilinos_ifpack2-adapters.so;/usr/lib/x86_64-linux-gnu/libtrilinos_ifpack2.so;/usr/lib/x86_64-linux-gnu/libtrilinos_anasazitpetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_ModeLaplace.so;/usr/lib/x86_64-linux-gnu/libtrilinos_anasaziepetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_anasazi.so;/usr/lib/x86_64-linux-gnu/libtrilinos_komplex.so;/usr/lib/x86_64-linux-gnu/libtrilinos_amesos2.so;/usr/lib/x86_64-linux-gnu/libtrilinos_tacho.so;/usr/lib/x86_64-linux-gnu/libtrilinos_shylu_nodehts.so;/usr/lib/x86_64-linux-gnu/libtrilinos_belosxpetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_belostpetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_belosepetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_belos.so;/usr/lib/x86_64-linux-gnu/libtrilinos_ml.so;/usr/lib/x86_64-linux-gnu/libtrilinos_ifpack.so;/usr/lib/x86_64-linux-gnu/libtrilinos_zoltan2.so;/usr/lib/x86_64-linux-gnu/libtrilinos_pamgen_extras.so;/usr/lib/x86_64-linux-gnu/libtrilinos_pamgen.so;/usr/lib/x86_64-linux-gnu/libtrilinos_amesos.so;/usr/lib/x86_64-linux-gnu/libtrilinos_galeri-xpetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_galeri-epetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_aztecoo.so;/usr/lib/x86_64-linux-gnu/libtrilinos_dpliris.so;/usr/lib/x86_64-linux-gnu/libtrilinos_isorropia.so;/usr/lib/x86_64-linux-gnu/libtrilinos_xpetra-sup.so;/usr/lib/x86_64-linux-gnu/libtrilinos_xpetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_thyratpetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_thyraepetraext.so;/usr/lib/x86_64-linux-gnu/libtrilinos_thyraepetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_thyracore.so;/usr/lib/x86_64-linux-gnu/libtrilinos_trilinosss.so;/usr/lib/x86_64-linux-gnu/libtrilinos_tpetraext.so;/usr/lib/x86_64-linux-gnu/libtrilinos_tpetrainout.so;/usr/lib/x86_64-linux-gnu/libtrilinos_tpetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_kokkostsqr.so;/usr/lib/x86_64-linux-gnu/libtrilinos_tpetraclassiclinalg.so;/usr/lib/x86_64-linux-gnu/libtrilinos_tpetraclassicnodeapi.so;/usr/lib/x86_64-linux-gnu/libtrilinos_tpetraclassic.so;/usr/lib/x86_64-linux-gnu/libtrilinos_epetraext.so;/usr/lib/x86_64-linux-gnu/libtrilinos_triutils.so;/usr/lib/x86_64-linux-gnu/libtrilinos_shards.so;/usr/lib/x86_64-linux-gnu/libtrilinos_zoltan.so;/usr/lib/x86_64-linux-gnu/libtrilinos_epetra.so;/usr/lib/x86_64-linux-gnu/libtrilinos_sacado.so;/usr/lib/x86_64-linux-gnu/libtrilinos_rtop.so;/usr/lib/x86_64-linux-gnu/libtrilinos_kokkoskernels.so;/usr/lib/x86_64-linux-gnu/libtrilinos_teuchoskokkoscomm.so;/usr/lib/x86_64-linux-gnu/libtrilinos_teuchoskokkoscompat.so;/usr/lib/x86_64-linux-gnu/libtrilinos_teuchosremainder.so;/usr/lib/x86_64-linux-gnu/libtrilinos_teuchosnumerics.so;/usr/lib/x86_64-linux-gnu/libtrilinos_teuchoscomm.so;/usr/lib/x86_64-linux-gnu/libtrilinos_teuchosparameterlist.so;/usr/lib/x86_64-linux-gnu/libtrilinos_teuchosparser.so;/usr/lib/x86_64-linux-gnu/libtrilinos_teuchoscore.so;/usr/lib/x86_64-linux-gnu/libtrilinos_kokkosalgorithms.so;/usr/lib/x86_64-linux-gnu/libtrilinos_kokkoscontainers.so;/usr/lib/x86_64-linux-gnu/libtrilinos_kokkoscore.so;/usr/lib/x86_64-linux-gnu/libtbb.so;/usr/lib/x86_64-linux-gnu/libsmumps.so;/usr/lib/x86_64-linux-gnu/libdmumps.so;/usr/lib/x86_64-linux-gnu/libcmumps.so;/usr/lib/x86_64-linux-gnu/libzmumps.so;/usr/lib/x86_64-linux-gnu/libpord.so;/usr/lib/x86_64-linux-gnu/libmumps_common.so;/usr/lib/x86_64-linux-gnu/hdf5/openmpi/libhdf5.so;/usr/lib/x86_64-linux-gnu/libptscotch.so;/usr/lib/x86_64-linux-gnu/libptscotcherr.so;/usr/lib/x86_64-linux-gnu/libscotch.so;/usr/lib/x86_64-linux-gnu/libscotcherr.so;/usr/lib/x86_64-linux-gnu/libdl.a;/usr/lib/x86_64-linux-gnu/openmpi/lib/libmpi_cxx.so;/usr/lib/x86_64-linux-gnu/libumfpack.so;/usr/lib/x86_64-linux-gnu/libcholmod.so;/usr/lib/x86_64-linux-gnu/libccolamd.so;/usr/lib/x86_64-linux-gnu/libcolamd.so;/usr/lib/x86_64-linux-gnu/libcamd.so;/usr/lib/x86_64-linux-gnu/libsuitesparseconfig.so;/usr/lib/x86_64-linux-gnu/libamd.so;/usr/lib/x86_64-linux-gnu/libmetis.so;rt;/usr/lib/x86_64-linux-gnu/libadolc.so;/usr/lib/x86_64-linux-gnu/libboost_iostreams.so;/usr/lib/x86_64-linux-gnu/libboost_serialization.so;/usr/lib/x86_64-linux-gnu/libboost_system.so;/usr/lib/x86_64-linux-gnu/libboost_thread.so;/usr/lib/x86_64-linux-gnu/libboost_regex.so;/usr/lib/x86_64-linux-gnu/libboost_chrono.so;/usr/lib/x86_64-linux-gnu/libboost_date_time.so;/usr/lib/x86_64-linux-gnu/libboost_atomic.so;/usr/lib/x86_64-linux-gnu/libparpack.so;/usr/lib/x86_64-linux-gnu/libarpack.so;/usr/lib/x86_64-linux-gnu/libassimp.so;/usr/lib/x86_64-linux-gnu/libgmsh.so;/usr/lib/x86_64-linux-gnu/libgsl.so;/usr/lib/x86_64-linux-gnu/libgslcblas.so;/usr/lib/x86_64-linux-gnu/hdf5/openmpi/lib/lib/libhdf5_hl.so;/usr/lib/x86_64-linux-gnu/hdf5/openmpi/lib/lib/libhdf5.so;/usr/lib/x86_64-linux-gnu/libmuparser.so;/usr/lib/x86_64-linux-gnu/libTKBO.so;/usr/lib/x86_64-linux-gnu/libTKBool.so;/usr/lib/x86_64-linux-gnu/libTKBRep.so;/usr/lib/x86_64-linux-gnu/libTKernel.so;/usr/lib/x86_64-linux-gnu/libTKFeat.so;/usr/lib/x86_64-linux-gnu/libTKFillet.so;/usr/lib/x86_64-linux-gnu/libTKG2d.so;/usr/lib/x86_64-linux-gnu/libTKG3d.so;/usr/lib/x86_64-linux-gnu/libTKGeomAlgo.so;/usr/lib/x86_64-linux-gnu/libTKGeomBase.so;/usr/lib/x86_64-linux-gnu/libTKHLR.so;/usr/lib/x86_64-linux-gnu/libTKIGES.so;/usr/lib/x86_64-linux-gnu/libTKMath.so;/usr/lib/x86_64-linux-gnu/libTKMesh.so;/usr/lib/x86_64-linux-gnu/libTKOffset.so;/usr/lib/x86_64-linux-gnu/libTKPrim.so;/usr/lib/x86_64-linux-gnu/libTKShHealing.so;/usr/lib/x86_64-linux-gnu/libTKSTEP.so;/usr/lib/x86_64-linux-gnu/libTKSTEPAttr.so;/usr/lib/x86_64-linux-gnu/libTKSTEPBase.so;/usr/lib/x86_64-linux-gnu/libTKSTEP209.so;/usr/lib/x86_64-linux-gnu/libTKSTL.so;/usr/lib/x86_64-linux-gnu/libTKTopAlgo.so;/usr/lib/x86_64-linux-gnu/libTKXSBase.so;/usr/lib/x86_64-linux-gnu/libp4est.so;/usr/lib/x86_64-linux-gnu/libsc.so;/usr/lib/x86_64-linux-gnu/libscalapack-openmpi.so;/usr/lib/x86_64-linux-gnu/liblapack.so;/usr/lib/x86_64-linux-gnu/libblas.so;/usr/lib/x86_64-linux-gnu/libmpi_usempif08.so;/usr/lib/x86_64-linux-gnu/libmpi_usempi_ignore_tkr.so;/usr/lib/x86_64-linux-gnu/libmpi_mpifh.so;/usr/lib/x86_64-linux-gnu/openmpi/lib/libmpi.so;/usr/lib/x86_64-linux-gnu/libopen-rte.so;/usr/lib/x86_64-linux-gnu/libopen-pal.so;/usr/lib/x86_64-linux-gnu/libhwloc.so;/usr/lib/x86_64-linux-gnu/libevent_core.so;/usr/lib/x86_64-linux-gnu/libevent_pthreads.so;m;/usr/lib/x86_64-linux-gnu/libz.so;/usr/lib/x86_64-linux-gnu/libslepc.so;/usr/lib/x86_64-linux-gnu/libpetsc.so;/usr/lib/x86_64-linux-gnu/libsundials_idas.so;/usr/lib/x86_64-linux-gnu/libsundials_arkode.so;/usr/lib/x86_64-linux-gnu/libsundials_kinsol.so;/usr/lib/x86_64-linux-gnu/libsundials_nvecserial.so;/usr/lib/x86_64-linux-gnu/libsundials_nvecparallel.so")

# Full list of libraries with "debug" and "optimized" keywords for easy use with TARGET_LINK_LIBRARIES:
SET(DEAL_II_LIBRARIES "debug;${DEAL_II_LIBRARIES_DEBUG};optimized;${DEAL_II_LIBRARIES_RELEASE}")


#
# Information about CUDA configuration
#

SET(DEAL_II_CUDA_TOOLKIT_ROOT_DIR "")
SET(DEAL_II_CUDA_COMPILER "")

# used for all cuda targets:
SET(DEAL_II_CUDA_FLAGS "")

# _additionally_ used for debug targets:
SET(DEAL_II_CUDA_FLAGS_DEBUG "")

# _additionally_ used for release targets:
SET(DEAL_II_CUDA_FLAGS_RELEASE "")


#
# Information about library targets and feature configuration
#

# The library targets file:
SET(DEAL_II_TARGET_CONFIG "${DEAL_II_PATH}/${DEAL_II_PROJECT_CONFIG_RELDIR}/${DEAL_II_PROJECT_CONFIG_NAME}Targets.cmake")

# The Debug target:
SET(DEAL_II_TARGET_DEBUG "deal.ii.g")

# The Release target:
SET(DEAL_II_TARGET_RELEASE "deal.ii")

# Full list of targets with "debug" and "optimized" keywords for easy use with TARGET_LINK_LIBRARIES:
SET(DEAL_II_TARGET "debug;${DEAL_II_TARGET_DEBUG};optimized;${DEAL_II_TARGET_RELEASE}")

# The feature configuration file:
SET(DEAL_II_FEATURE_CONFIG "${DEAL_II_PATH}/${DEAL_II_PROJECT_CONFIG_RELDIR}/${DEAL_II_PROJECT_CONFIG_NAME}FeatureConfig.cmake")


#
# Feature configuration:
#

SET(DEAL_II_WITH_CXX11 ON)
SET(DEAL_II_WITH_CXX14 ON)
SET(DEAL_II_WITH_CXX17 TRUE)
SET(DEAL_II_WITH_THREADS ON)
SET(DEAL_II_WITH_64BIT_INDICES OFF)
SET(DEAL_II_WITH_ADOLC ON)
SET(DEAL_II_ADOLC_WITH_ADVANCED_BRANCHING FALSE)
SET(DEAL_II_ADOLC_WITH_ATRIG_ERF TRUE)
SET(DEAL_II_ADOLC_WITH_BOOST_ALLOCATOR TRUE)
SET(DEAL_II_ADOLC_WITH_TAPELESS_REFCOUNTING FALSE)
SET(DEAL_II_WITH_ARBORX OFF)
SET(DEAL_II_WITH_ARPACK ON)
SET(DEAL_II_ARPACK_WITH_PARPACK TRUE)
SET(DEAL_II_WITH_ASSIMP ON)
SET(DEAL_II_WITH_BOOST ON)
SET(DEAL_II_BOOST_VERSION "1.74.0")
SET(DEAL_II_WITH_COMPLEX_VALUES ON)
SET(DEAL_II_WITH_CUDA OFF)
SET(DEAL_II_WITH_GINKGO OFF)
SET(DEAL_II_WITH_GMSH ON)
SET(DEAL_II_GMSH_WITH_API TRUE)
SET(DEAL_II_WITH_GSL ON)
SET(DEAL_II_GSL_VERSION "7.1")
SET(DEAL_II_WITH_HDF5 ON)
SET(DEAL_II_WITH_KOKKOS ON)
SET(DEAL_II_WITH_LAPACK ON)
SET(DEAL_II_LAPACK_WITH_MKL OFF)
SET(DEAL_II_WITH_METIS ON)
SET(DEAL_II_METIS_VERSION "5.1.0")
SET(DEAL_II_WITH_MPI ON)
SET(DEAL_II_MPI_VERSION "3.1")
SET(DEAL_II_MPI_WITH_CUDA_SUPPORT OFF)
SET(DEAL_II_WITH_MUPARSER ON)
SET(DEAL_II_MUPARSER_VERSION "2.2.6")
SET(DEAL_II_WITH_OPENCASCADE ON)
SET(DEAL_II_OPENCASCADE_VERSION "7.5.1")
SET(DEAL_II_WITH_P4EST ON)
SET(DEAL_II_P4EST_VERSION "2.2")
SET(DEAL_II_P4EST_WITH_VTK_BINARY TRUE)
SET(DEAL_II_WITH_PETSC ON)
SET(DEAL_II_PETSC_VERSION "3.15.5.0")
SET(DEAL_II_PETSC_WITH_COMPLEX FALSE)
SET(DEAL_II_PETSC_WITH_HYPRE TRUE)
SET(DEAL_II_PETSC_WITH_MUMPS TRUE)
SET(DEAL_II_WITH_SCALAPACK ON)
SET(DEAL_II_WITH_SLEPC ON)
SET(DEAL_II_SLEPC_VERSION "3.15.2.0")
SET(DEAL_II_WITH_SUNDIALS ON)
SET(DEAL_II_SUNDIALS_VERSION "5.8.0")
SET(DEAL_II_SUNDIALS_WITH_IDAS TRUE)
SET(DEAL_II_WITH_SYMENGINE OFF)
SET(DEAL_II_WITH_TBB ON)
SET(DEAL_II_TBB_VERSION "2020.3")
SET(DEAL_II_WITH_TRILINOS ON)
SET(DEAL_II_TRILINOS_VERSION "13.2")
SET(DEAL_II_TRILINOS_WITH_EPETRAEXT ON)
SET(DEAL_II_TRILINOS_WITH_KOKKOS ON)
SET(DEAL_II_TRILINOS_WITH_MUELU OFF)
SET(DEAL_II_TRILINOS_WITH_MUMPS ON)
SET(DEAL_II_TRILINOS_WITH_ROL ON)
SET(DEAL_II_TRILINOS_WITH_SACADO ON)
SET(DEAL_II_TRILINOS_WITH_TPETRA OFF)
SET(DEAL_II_TRILINOS_WITH_ZOLTAN ON)
SET(DEAL_II_WITH_UMFPACK ON)
SET(DEAL_II_UMFPACK_VERSION "5.7.9")
SET(DEAL_II_WITH_ZLIB ON)
SET(DEAL_II_ZLIB_VERSION "1.2.11")
